History
-------

1.0.4
+++++
released 2018-2-27

- Fix rule variable in numeric rule

1.0.3
+++++
released 2018-2-26

- Add rule variable support to numeric rule

1.0.2
+++++
released 2018-2-10

- Add string `not_equal_to`.

1.0.1
+++++
released 2016-3-16

- Fixes a packaging bug preventing 1.0.0 from being installed on some platforms.

1.0.0
+++++
released 2016-3-16

- Removes caching layer on rule decorator
